@@ -1,20 +1,16 @@
-# -*- coding: utf-8 -*-
 """
 This is the default grains PCRE matcher.
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 
-import salt.utils.data  # pylint: disable=3rd-party-module-not-gated
-from salt.defaults import (  # pylint: disable=3rd-party-module-not-gated
-    DEFAULT_TARGET_DELIM,
-)
+import salt.utils.data
+from salt.defaults import DEFAULT_TARGET_DELIM
 
 log = logging.getLogger(__name__)
 
 
-def match(tgt, delimiter=DEFAULT_TARGET_DELIM, opts=None):
+def match(tgt, delimiter=DEFAULT_TARGET_DELIM, opts=None, minion_id=None):
     """
     Matches a grain based on regex
     """
@@ -23,7 +19,7 @@ def match(tgt, delimiter=DEFAULT_TARGET_DELIM, opts=None):
     log.debug("grains pcre target: %s", tgt)
     if delimiter not in tgt:
         log.error(
-            "Got insufficient arguments for grains pcre match " "statement from master"
+            "Got insufficient arguments for grains pcre match statement from master"
         )
         return False
 
