@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Display values only, separated by newlines
 ==========================================
 
@@ -27,6 +27,10 @@ the various minions.
 Example 1
 ~~~~~~~~~
 
+.. code-block:: bash
+
+    salt '*' foo.bar --out=newline_values_only
+
 Input
 -----
 
@@ -40,7 +44,7 @@ Input
 Output
 ------
 
-.. code-block:: python
+.. code-block:: text
 
     127.0.0.1
     10.0.0.1
@@ -50,6 +54,10 @@ Output
 Example 2
 ~~~~~~~~~
 
+.. code-block:: bash
+
+    salt '*' foo.bar --out=newline_values_only
+
 Input
 -----
 
@@ -67,7 +75,7 @@ Output
 
     8
     10
-'''
+"""
 
 # Import python libs
 from __future__ import absolute_import, print_function, unicode_literals
@@ -94,7 +102,7 @@ def _get_values(data):
 
 
 def _one_level_values(data):
-    return '\n'.join(_string_list(_get_values(data)))
+    return "\n".join(_string_list(_get_values(data)))
 
 
 def _string_list(a_list):
@@ -102,7 +110,7 @@ def _string_list(a_list):
 
 
 def output(data, **kwargs):  # pylint: disable=unused-argument
-    '''
+    """
     Display modified ret data
-    '''
+    """
     return _one_level_values(data)
