@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Return data to a PostgreSQL server with json data stored in Pg's jsonb data type
 
 :maintainer:    Dave Boucha <dave@saltstack.com>, Seth House <shouse@saltstack.com>, C. R. Oldham <cr@saltstack.com>
@@ -159,27 +159,32 @@ To override individual configuration items, append --return_kwargs '{"key:": "va
 
     salt '*' test.ping --return pgjsonb --return_kwargs '{"db": "another-salt"}'
 
-'''
+"""
 from __future__ import absolute_import, print_function, unicode_literals
-# Let's not allow PyLint complain about string substitution
-# pylint: disable=W1321,E1321
+
+import logging
+import sys
+import time
 
 # Import python libs
 from contextlib import contextmanager
-import sys
-import time
-import logging
+
+import salt.exceptions
 
 # Import salt libs
 import salt.returners
 import salt.utils.jid
-import salt.exceptions
 from salt.ext import six
 
+# Let's not allow PyLint complain about string substitution
+# pylint: disable=W1321,E1321
+
+
 # Import third party libs
 try:
     import psycopg2
     import psycopg2.extras
+
     HAS_PG = True
 except ImportError:
     HAS_PG = False
@@ -187,85 +192,93 @@ except ImportError:
 log = logging.getLogger(__name__)
 
 # Define the module's virtual name
-__virtualname__ = 'pgjsonb'
+__virtualname__ = "pgjsonb"
 
-PG_SAVE_LOAD_SQL = '''INSERT INTO jids (jid, load) VALUES (%(jid)s, %(load)s)'''
+PG_SAVE_LOAD_SQL = """INSERT INTO jids (jid, load) VALUES (%(jid)s, %(load)s)"""
 
 
 def __virtual__():
     if not HAS_PG:
-        return False, 'Could not import pgjsonb returner; python-psycopg2 is not installed.'
+        return (
+            False,
+            "Could not import pgjsonb returner; python-psycopg2 is not installed.",
+        )
     return True
 
 
 def _get_options(ret=None):
-    '''
+    """
     Returns options used for the MySQL connection.
-    '''
+    """
     defaults = {
-        'host': 'localhost',
-        'user': 'salt',
-        'pass': 'salt',
-        'db': 'salt',
-        'port': 5432
+        "host": "localhost",
+        "user": "salt",
+        "pass": "salt",
+        "db": "salt",
+        "port": 5432,
     }
 
     attrs = {
-        'host': 'host',
-        'user': 'user',
-        'pass': 'pass',
-        'db': 'db',
-        'port': 'port',
-        'sslmode': 'sslmode',
-        'sslcert': 'sslcert',
-        'sslkey': 'sslkey',
-        'sslrootcert': 'sslrootcert',
-        'sslcrl': 'sslcrl',
+        "host": "host",
+        "user": "user",
+        "pass": "pass",
+        "db": "db",
+        "port": "port",
+        "sslmode": "sslmode",
+        "sslcert": "sslcert",
+        "sslkey": "sslkey",
+        "sslrootcert": "sslrootcert",
+        "sslcrl": "sslcrl",
     }
 
-    _options = salt.returners.get_returner_options('returner.{0}'.format(__virtualname__),
-                                                   ret,
-                                                   attrs,
-                                                   __salt__=__salt__,
-                                                   __opts__=__opts__,
-                                                   defaults=defaults)
+    _options = salt.returners.get_returner_options(
+        "returner.{0}".format(__virtualname__),
+        ret,
+        attrs,
+        __salt__=__salt__,
+        __opts__=__opts__,
+        defaults=defaults,
+    )
     # Ensure port is an int
-    if 'port' in _options:
-        _options['port'] = int(_options['port'])
+    if "port" in _options:
+        _options["port"] = int(_options["port"])
     return _options
 
 
 @contextmanager
 def _get_serv(ret=None, commit=False):
-    '''
+    """
     Return a Pg cursor
-    '''
+    """
     _options = _get_options(ret)
     try:
         # An empty ssl_options dictionary passed to MySQLdb.connect will
         # effectively connect w/o SSL.
         ssl_options = {
-            k: v for k, v in six.iteritems(_options)
-            if k in ['sslmode', 'sslcert', 'sslkey', 'sslrootcert', 'sslcrl']
+            k: v
+            for k, v in six.iteritems(_options)
+            if k in ["sslmode", "sslcert", "sslkey", "sslrootcert", "sslcrl"]
         }
         conn = psycopg2.connect(
-            host=_options.get('host'),
-            port=_options.get('port'),
-            dbname=_options.get('db'),
-            user=_options.get('user'),
-            password=_options.get('pass'),
+            host=_options.get("host"),
+            port=_options.get("port"),
+            dbname=_options.get("db"),
+            user=_options.get("user"),
+            password=_options.get("pass"),
             **ssl_options
         )
     except psycopg2.OperationalError as exc:
-        raise salt.exceptions.SaltMasterError('pgjsonb returner could not connect to database: {exc}'.format(exc=exc))
+        raise salt.exceptions.SaltMasterError(
+            "pgjsonb returner could not connect to database: {exc}".format(exc=exc)
+        )
 
     if conn.server_version is not None and conn.server_version >= 90500:
         global PG_SAVE_LOAD_SQL
-        PG_SAVE_LOAD_SQL = '''INSERT INTO jids
+        PG_SAVE_LOAD_SQL = """INSERT INTO jids
                               (jid, load)
                               VALUES (%(jid)s, %(load)s)
                               ON CONFLICT (jid) DO UPDATE
-                              SET load=%(load)s'''
+                              SET load=%(load)s"""
 
     cursor = conn.cursor()
 
@@ -275,7 +288,7 @@ def _get_serv(ret=None, commit=False):
         error = err.args
         sys.stderr.write(six.text_type(error))
         cursor.execute("ROLLBACK")
-        raise err
+        six.reraise(*sys.exc_info())
     else:
         if commit:
             cursor.execute("COMMIT")
@@ -286,50 +299,60 @@ def _get_serv(ret=None, commit=False):
 
 
 def returner(ret):
-    '''
+    """
     Return data to a Pg server
-    '''
+    """
     try:
         with _get_serv(ret, commit=True) as cur:
-            sql = '''INSERT INTO salt_returns
+            sql = """INSERT INTO salt_returns
                     (fun, jid, return, id, success, full_ret, alter_time)
-                    VALUES (%s, %s, %s, %s, %s, %s, to_timestamp(%s))'''
+                    VALUES (%s, %s, %s, %s, %s, %s, to_timestamp(%s))"""
 
-            cur.execute(sql, (ret['fun'], ret['jid'],
-                              psycopg2.extras.Json(ret['return']),
-                              ret['id'],
-                              ret.get('success', False),
-                              psycopg2.extras.Json(ret),
-                              time.time()))
+            cur.execute(
+                sql,
+                (
+                    ret["fun"],
+                    ret["jid"],
+                    psycopg2.extras.Json(ret["return"]),
+                    ret["id"],
+                    ret.get("success", False),
+                    psycopg2.extras.Json(ret),
+                    time.time(),
+                ),
+            )
     except salt.exceptions.SaltMasterError:
-        log.critical('Could not store return with pgjsonb returner. PostgreSQL server unavailable.')
+        log.critical(
+            "Could not store return with pgjsonb returner. PostgreSQL server unavailable."
+        )
 
 
 def event_return(events):
-    '''
+    """
     Return event to Pg server
 
     Requires that configuration be enabled via 'event_return'
     option in master config.
-    '''
+    """
     with _get_serv(events, commit=True) as cur:
         for event in events:
-            tag = event.get('tag', '')
-            data = event.get('data', '')
-            sql = '''INSERT INTO salt_events (tag, data, master_id, alter_time)
-                     VALUES (%s, %s, %s, to_timestamp(%s))'''
-            cur.execute(sql, (tag, psycopg2.extras.Json(data),
-                              __opts__['id'], time.time()))
+            tag = event.get("tag", "")
+            data = event.get("data", "")
+            sql = """INSERT INTO salt_events (tag, data, master_id, alter_time)
+                     VALUES (%s, %s, %s, to_timestamp(%s))"""
+            cur.execute(
+                sql, (tag, psycopg2.extras.Json(data), __opts__["id"], time.time())
+            )
 
 
 def save_load(jid, load, minions=None):
-    '''
+    """
     Save the load to the specified jid id
-    '''
+    """
     with _get_serv(commit=True) as cur:
         try:
-            cur.execute(PG_SAVE_LOAD_SQL,
-                        {'jid': jid, 'load': psycopg2.extras.Json(load)})
+            cur.execute(
+                PG_SAVE_LOAD_SQL, {"jid": jid, "load": psycopg2.extras.Json(load)}
+            )
         except psycopg2.IntegrityError:
             # https://github.com/saltstack/salt/issues/22171
             # Without this try/except we get tons of duplicate entry errors
@@ -338,19 +361,18 @@ def save_load(jid, load, minions=None):
 
 
 def save_minions(jid, minions, syndic_id=None):  # pylint: disable=unused-argument
-    '''
+    """
     Included for API consistency
-    '''
-    pass
+    """
 
 
 def get_load(jid):
-    '''
+    """
     Return the load data that marks a specified jid
-    '''
+    """
     with _get_serv(ret=None, commit=True) as cur:
 
-        sql = '''SELECT load FROM jids WHERE jid = %s;'''
+        sql = """SELECT load FROM jids WHERE jid = %s;"""
         cur.execute(sql, (jid,))
         data = cur.fetchone()
         if data:
@@ -359,13 +381,13 @@ def get_load(jid):
 
 
 def get_jid(jid):
-    '''
+    """
     Return the information returned when the specified job id was executed
-    '''
+    """
     with _get_serv(ret=None, commit=True) as cur:
 
-        sql = '''SELECT id, full_ret FROM salt_returns
-                WHERE jid = %s'''
+        sql = """SELECT id, full_ret FROM salt_returns
+                WHERE jid = %s"""
 
         cur.execute(sql, (jid,))
         data = cur.fetchall()
@@ -377,18 +399,18 @@ def get_jid(jid):
 
 
 def get_fun(fun):
-    '''
+    """
     Return a dict of the last function called for all minions
-    '''
+    """
     with _get_serv(ret=None, commit=True) as cur:
 
-        sql = '''SELECT s.id,s.jid, s.full_ret
+        sql = """SELECT s.id,s.jid, s.full_ret
                 FROM salt_returns s
                 JOIN ( SELECT MAX(`jid`) as jid
                     from salt_returns GROUP BY fun, id) max
                 ON s.jid = max.jid
                 WHERE s.fun = %s
-                '''
+                """
 
         cur.execute(sql, (fun,))
         data = cur.fetchall()
@@ -401,13 +423,13 @@ def get_fun(fun):
 
 
 def get_jids():
-    '''
+    """
     Return a list of all job ids
-    '''
+    """
     with _get_serv(ret=None, commit=True) as cur:
 
-        sql = '''SELECT jid, load
-                FROM jids'''
+        sql = """SELECT jid, load
+                FROM jids"""
 
         cur.execute(sql)
         data = cur.fetchall()
@@ -418,13 +440,13 @@ def get_jids():
 
 
 def get_minions():
-    '''
+    """
     Return a list of minions
-    '''
+    """
     with _get_serv(ret=None, commit=True) as cur:
 
-        sql = '''SELECT DISTINCT id
-                FROM salt_returns'''
+        sql = """SELECT DISTINCT id
+                FROM salt_returns"""
 
         cur.execute(sql)
         data = cur.fetchall()
@@ -435,23 +457,23 @@ def get_minions():
 
 
 def prep_jid(nocache=False, passed_jid=None):  # pylint: disable=unused-argument
-    '''
+    """
     Do any work necessary to prepare a JID, including sending a custom id
-    '''
+    """
     return passed_jid if passed_jid is not None else salt.utils.jid.gen_jid(__opts__)
 
 
 def _purge_jobs(timestamp):
-    '''
+    """
     Purge records from the returner tables.
     :param job_age_in_seconds:  Purge jobs older than this
     :return:
-    '''
+    """
     with _get_serv() as cursor:
         try:
-            sql = 'delete from jids where jid in (select distinct jid from salt_returns where alter_time < %s)'
+            sql = "delete from jids where jid in (select distinct jid from salt_returns where alter_time < %s)"
             cursor.execute(sql, (timestamp,))
-            cursor.execute('COMMIT')
+            cursor.execute("COMMIT")
         except psycopg2.DatabaseError as err:
             error = err.args
             sys.stderr.write(six.text_type(error))
@@ -459,9 +481,9 @@ def _purge_jobs(timestamp):
             raise err
 
         try:
-            sql = 'delete from salt_returns where alter_time < %s'
+            sql = "delete from salt_returns where alter_time < %s"
             cursor.execute(sql, (timestamp,))
-            cursor.execute('COMMIT')
+            cursor.execute("COMMIT")
         except psycopg2.DatabaseError as err:
             error = err.args
             sys.stderr.write(six.text_type(error))
@@ -469,9 +491,9 @@ def _purge_jobs(timestamp):
             raise err
 
         try:
-            sql = 'delete from salt_events where alter_time < %s'
+            sql = "delete from salt_events where alter_time < %s"
             cursor.execute(sql, (timestamp,))
-            cursor.execute('COMMIT')
+            cursor.execute("COMMIT")
         except psycopg2.DatabaseError as err:
             error = err.args
             sys.stderr.write(six.text_type(error))
@@ -482,23 +504,23 @@ def _purge_jobs(timestamp):
 
 
 def _archive_jobs(timestamp):
-    '''
+    """
     Copy rows to a set of backup tables, then purge rows.
     :param timestamp: Archive rows older than this timestamp
     :return:
-    '''
-    source_tables = ['jids',
-                     'salt_returns',
-                     'salt_events']
+    """
+    source_tables = ["jids", "salt_returns", "salt_events"]
 
     with _get_serv() as cursor:
         target_tables = {}
         for table_name in source_tables:
             try:
-                tmp_table_name = table_name + '_archive'
-                sql = 'create table IF NOT exists {0} (LIKE {1})'.format(tmp_table_name, table_name)
+                tmp_table_name = table_name + "_archive"
+                sql = "create table IF NOT exists {0} (LIKE {1})".format(
+                    tmp_table_name, table_name
+                )
                 cursor.execute(sql)
-                cursor.execute('COMMIT')
+                cursor.execute("COMMIT")
                 target_tables[table_name] = tmp_table_name
             except psycopg2.DatabaseError as err:
                 error = err.args
@@ -507,22 +529,26 @@ def _archive_jobs(timestamp):
                 raise err
 
         try:
-            sql = 'insert into {0} select * from {1} where jid in (select distinct jid from salt_returns where alter_time < %s)'.format(target_tables['jids'], 'jids')
+            sql = "insert into {0} select * from {1} where jid in (select distinct jid from salt_returns where alter_time < %s)".format(
+                target_tables["jids"], "jids"
+            )
             cursor.execute(sql, (timestamp,))
-            cursor.execute('COMMIT')
+            cursor.execute("COMMIT")
         except psycopg2.DatabaseError as err:
             error = err.args
             sys.stderr.write(six.text_type(error))
             cursor.execute("ROLLBACK")
             raise err
-        except Exception as e:
+        except Exception as e:  # pylint: disable=broad-except
             log.error(e)
             raise
 
         try:
-            sql = 'insert into {0} select * from {1} where alter_time < %s'.format(target_tables['salt_returns'], 'salt_returns')
+            sql = "insert into {0} select * from {1} where alter_time < %s".format(
+                target_tables["salt_returns"], "salt_returns"
+            )
             cursor.execute(sql, (timestamp,))
-            cursor.execute('COMMIT')
+            cursor.execute("COMMIT")
         except psycopg2.DatabaseError as err:
             error = err.args
             sys.stderr.write(six.text_type(error))
@@ -530,9 +556,11 @@ def _archive_jobs(timestamp):
             raise err
 
         try:
-            sql = 'insert into {0} select * from {1} where alter_time < %s'.format(target_tables['salt_events'], 'salt_events')
+            sql = "insert into {0} select * from {1} where alter_time < %s".format(
+                target_tables["salt_events"], "salt_events"
+            )
             cursor.execute(sql, (timestamp,))
-            cursor.execute('COMMIT')
+            cursor.execute("COMMIT")
         except psycopg2.DatabaseError as err:
             error = err.args
             sys.stderr.write(six.text_type(error))
@@ -543,22 +571,24 @@ def _archive_jobs(timestamp):
 
 
 def clean_old_jobs():
-    '''
+    """
     Called in the master's event loop every loop_interval.  Archives and/or
     deletes the events and job details from the database.
     :return:
-    '''
-    if __opts__.get('keep_jobs', False) and int(__opts__.get('keep_jobs', 0)) > 0:
+    """
+    if __opts__.get("keep_jobs", False) and int(__opts__.get("keep_jobs", 0)) > 0:
         try:
             with _get_serv() as cur:
-                sql = "select (NOW() -  interval '{0}' hour) as stamp;".format(__opts__['keep_jobs'])
+                sql = "select (NOW() -  interval '{0}' hour) as stamp;".format(
+                    __opts__["keep_jobs"]
+                )
                 cur.execute(sql)
                 rows = cur.fetchall()
                 stamp = rows[0][0]
 
-            if __opts__.get('archive_jobs', False):
+            if __opts__.get("archive_jobs", False):
                 _archive_jobs(stamp)
             else:
                 _purge_jobs(stamp)
-        except Exception as e:
+        except Exception as e:  # pylint: disable=broad-except
             log.error(e)
