@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 This module helps include encrypted passwords in pillars, grains and salt state files.
 
 :depends: libnacl, https://github.com/saltstack/libnacl
@@ -110,23 +109,22 @@ Larger files like certificates can be encrypted with:
 
     salt-run nacl.enc_file /tmp/cert.crt out=/tmp/cert.nacl
 
-'''
+"""
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import Salt libs
 import salt.utils.nacl
 
-__virtualname__ = 'nacl'
+__virtualname__ = "nacl"
 
 
 def __virtual__():
+    if __opts__["fips_mode"] is True:
+        return False, "nacl runner not available in FIPS mode"
     return salt.utils.nacl.check_requirements()
 
 
 def keygen(sk_file=None, pk_file=None, **kwargs):
-    '''
+    """
     Use libnacl to generate a keypair.
 
     If no `sk_file` is defined return a keypair.
@@ -144,23 +142,23 @@ def keygen(sk_file=None, pk_file=None, **kwargs):
         salt-run nacl.keygen sk_file=/etc/salt/pki/master/nacl
         salt-run nacl.keygen sk_file=/etc/salt/pki/master/nacl pk_file=/etc/salt/pki/master/nacl.pub
         salt-run nacl.keygen
-    '''
-    kwargs['opts'] = __opts__
+    """
+    kwargs["opts"] = __opts__
     return salt.utils.nacl.keygen(sk_file, pk_file, **kwargs)
 
 
 def enc(data, **kwargs):
-    '''
+    """
     Alias to `{box_type}_encrypt`
 
     box_type: secretbox, sealedbox(default)
-    '''
-    kwargs['opts'] = __opts__
+    """
+    kwargs["opts"] = __opts__
     return salt.utils.nacl.enc(data, **kwargs)
 
 
 def enc_file(name, out=None, **kwargs):
-    '''
+    """
     This is a helper function to encrypt a file and return its contents.
 
     You can provide an optional output file using `out`
@@ -174,23 +172,23 @@ def enc_file(name, out=None, **kwargs):
         salt-run nacl.enc_file name=/tmp/id_rsa
         salt-run nacl.enc_file name=/tmp/id_rsa box_type=secretbox \
             sk_file=/etc/salt/pki/master/nacl.pub
-    '''
-    kwargs['opts'] = __opts__
+    """
+    kwargs["opts"] = __opts__
     return salt.utils.nacl.enc_file(name, out, **kwargs)
 
 
 def dec(data, **kwargs):
-    '''
+    """
     Alias to `{box_type}_decrypt`
 
     box_type: secretbox, sealedbox(default)
-    '''
-    kwargs['opts'] = __opts__
+    """
+    kwargs["opts"] = __opts__
     return salt.utils.nacl.dec(data, **kwargs)
 
 
 def dec_file(name, out=None, **kwargs):
-    '''
+    """
     This is a helper function to decrypt a file and return its contents.
 
     You can provide an optional output file using `out`
@@ -204,13 +202,13 @@ def dec_file(name, out=None, **kwargs):
         salt-run nacl.dec_file name=/tmp/id_rsa.nacl
         salt-run nacl.dec_file name=/tmp/id_rsa.nacl box_type=secretbox \
             sk_file=/etc/salt/pki/master/nacl.pub
-    '''
-    kwargs['opts'] = __opts__
+    """
+    kwargs["opts"] = __opts__
     return salt.utils.nacl.dec_file(name, out, **kwargs)
 
 
 def sealedbox_encrypt(data, **kwargs):
-    '''
+    """
     Encrypt data using a public key generated from `nacl.keygen`.
     The encryptd data can be decrypted using `nacl.sealedbox_decrypt` only with the secret key.
 
@@ -219,13 +217,13 @@ def sealedbox_encrypt(data, **kwargs):
     .. code-block:: bash
 
         salt-run nacl.sealedbox_encrypt datatoenc
-    '''
-    kwargs['opts'] = __opts__
+    """
+    kwargs["opts"] = __opts__
     return salt.utils.nacl.sealedbox_encrypt(data, **kwargs)
 
 
 def sealedbox_decrypt(data, **kwargs):
-    '''
+    """
     Decrypt data using a secret key that was encrypted using a public key with `nacl.sealedbox_encrypt`.
 
     CLI Examples:
@@ -235,13 +233,13 @@ def sealedbox_decrypt(data, **kwargs):
         salt-run nacl.sealedbox_decrypt pEXHQM6cuaF7A=
         salt-run nacl.sealedbox_decrypt data='pEXHQM6cuaF7A=' sk_file=/etc/salt/pki/master/nacl
         salt-run nacl.sealedbox_decrypt data='pEXHQM6cuaF7A=' sk='YmFkcGFzcwo='
-    '''
-    kwargs['opts'] = __opts__
+    """
+    kwargs["opts"] = __opts__
     return salt.utils.nacl.sealedbox_decrypt(data, **kwargs)
 
 
 def secretbox_encrypt(data, **kwargs):
-    '''
+    """
     Encrypt data using a secret key generated from `nacl.keygen`.
     The same secret key can be used to decrypt the data using `nacl.secretbox_decrypt`.
 
@@ -252,13 +250,13 @@ def secretbox_encrypt(data, **kwargs):
         salt-run nacl.secretbox_encrypt datatoenc
         salt-run nacl.secretbox_encrypt datatoenc sk_file=/etc/salt/pki/master/nacl
         salt-run nacl.secretbox_encrypt datatoenc sk='YmFkcGFzcwo='
-    '''
-    kwargs['opts'] = __opts__
+    """
+    kwargs["opts"] = __opts__
     return salt.utils.nacl.secretbox_encrypt(data, **kwargs)
 
 
 def secretbox_decrypt(data, **kwargs):
-    '''
+    """
     Decrypt data that was encrypted using `nacl.secretbox_encrypt` using the secret key
     that was generated from `nacl.keygen`.
 
@@ -269,6 +267,6 @@ def secretbox_decrypt(data, **kwargs):
         salt-run nacl.secretbox_decrypt pEXHQM6cuaF7A=
         salt-run nacl.secretbox_decrypt data='pEXHQM6cuaF7A=' sk_file=/etc/salt/pki/master/nacl
         salt-run nacl.secretbox_decrypt data='pEXHQM6cuaF7A=' sk='YmFkcGFzcwo='
-    '''
-    kwargs['opts'] = __opts__
+    """
+    kwargs["opts"] = __opts__
     return salt.utils.nacl.secretbox_decrypt(data, **kwargs)
