@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Support for getting and setting the environment variables
 of the current salt process.
-'''
+"""
 
 # Import Python libs
 from __future__ import absolute_import, print_function, unicode_literals
+
 import os
 
 # Import Salt libs
@@ -16,28 +17,30 @@ from salt.ext import six
 
 
 def __virtual__():
-    '''
+    """
     No dependency checks, and not renaming, just return True
-    '''
+    """
     return True
 
 
 def _norm_key(key):
-    '''
+    """
     Normalize windows environment keys
-    '''
+    """
     if salt.utils.platform.is_windows():
         return key.upper()
     return key
 
 
-def setenv(name,
-           value,
-           false_unsets=False,
-           clear_all=False,
-           update_minion=False,
-           permanent=False):
-    '''
+def setenv(
+    name,
+    value,
+    false_unsets=False,
+    clear_all=False,
+    update_minion=False,
+    permanent=False,
+):
+    """
     Set the salt process environment variables.
 
     name
@@ -93,20 +96,17 @@ def setenv(name,
              - value:
                  foo: bar
                  baz: quux
-    '''
+    """
 
-    ret = {'name': name,
-           'changes': {},
-           'result': True,
-           'comment': ''}
+    ret = {"name": name, "changes": {}, "result": True, "comment": ""}
     environ = {}
     if isinstance(value, six.string_types) or value is False:
         environ[name] = value
     elif isinstance(value, dict):
         environ = value
     else:
-        ret['result'] = False
-        ret['comment'] = 'Environ value must be string, dict or False'
+        ret["result"] = False
+        ret["comment"] = "Environ value must be string, dict or False"
         return ret
 
     if clear_all is True:
@@ -115,10 +115,10 @@ def setenv(name,
         for key in to_unset:
             if false_unsets is not True:
                 # This key value will change to ''
-                ret['changes'].update({key: ''})
+                ret["changes"].update({key: ""})
             else:
                 # We're going to delete the key
-                ret['changes'].update({key: None})
+                ret["changes"].update({key: None})
 
     current_environ = dict(os.environ)
     already_set = []
@@ -129,56 +129,57 @@ def setenv(name,
             # the value to ''
             def key_exists():
                 if salt.utils.platform.is_windows():
-                    permanent_hive = 'HKCU'
-                    permanent_key = 'Environment'
-                    if permanent == 'HKLM':
-                        permanent_hive = 'HKLM'
-                        permanent_key = r'SYSTEM\CurrentControlSet\Control\Session Manager\Environment'
+                    permanent_hive = "HKCU"
+                    permanent_key = "Environment"
+                    if permanent == "HKLM":
+                        permanent_hive = "HKLM"
+                        permanent_key = r"SYSTEM\CurrentControlSet\Control\Session Manager\Environment"
 
-                    out = __salt__['reg.read_value'](permanent_hive, permanent_key, _norm_key(key))
-                    return out['success'] is True
+                    out = __utils__["reg.read_value"](
+                        permanent_hive, permanent_key, _norm_key(key)
+                    )
+                    return out["success"] is True
                 else:
                     return False
+
             if current_environ.get(_norm_key(key), None) is None and not key_exists():
                 # The key does not exist in environment
                 if false_unsets is not True:
                     # This key will be added with value ''
-                    ret['changes'].update({key: ''})
+                    ret["changes"].update({key: ""})
             else:
                 # The key exists.
                 if false_unsets is not True:
                     # Check to see if the value will change
-                    if current_environ.get(_norm_key(key), None) != '':
+                    if current_environ.get(_norm_key(key), None) != "":
                         # This key value will change to ''
-                        ret['changes'].update({key: ''})
+                        ret["changes"].update({key: ""})
                 else:
                     # We're going to delete the key
-                    ret['changes'].update({key: None})
-        elif current_environ.get(_norm_key(key), '') == val:
+                    ret["changes"].update({key: None})
+        elif current_environ.get(_norm_key(key), "") == val:
             already_set.append(key)
         else:
-            ret['changes'].update({key: val})
+            ret["changes"].update({key: val})
 
-    if __opts__['test']:
-        if ret['changes']:
-            ret['comment'] = 'Environ values will be changed'
+    if __opts__["test"]:
+        if ret["changes"]:
+            ret["comment"] = "Environ values will be changed"
         else:
-            ret['comment'] = 'Environ values are already set with the correct values'
+            ret["comment"] = "Environ values are already set with the correct values"
         return ret
 
-    if ret['changes']:
-        environ_ret = __salt__['environ.setenv'](environ,
-                                                 false_unsets,
-                                                 clear_all,
-                                                 update_minion,
-                                                 permanent)
+    if ret["changes"]:
+        environ_ret = __salt__["environ.setenv"](
+            environ, false_unsets, clear_all, update_minion, permanent
+        )
         if not environ_ret:
-            ret['result'] = False
-            ret['comment'] = 'Failed to set environ variables'
+            ret["result"] = False
+            ret["comment"] = "Failed to set environ variables"
             return ret
-        ret['result'] = True
-        ret['changes'] = environ_ret
-        ret['comment'] = 'Environ values were set'
+        ret["result"] = True
+        ret["changes"] = environ_ret
+        ret["comment"] = "Environ values were set"
     else:
-        ret['comment'] = 'Environ values were already set with the correct values'
+        ret["comment"] = "Environ values were already set with the correct values"
     return ret
